@@ -46,8 +46,10 @@ NULL
 #' pattern is used to turn on or off blocks of SQL code.} }
 #'
 #'
-#' @param sql   The parameterized SQL
-#' @param ...   Parameter values
+#' @param sql                         The parameterized SQL
+#' @param warnOnMissingParameters     Should a warning be raised when parameters provided to this function 
+#'                                    do not appear in the parameterized SQL that is being rendered? By default, this is TRUE.
+#' @param ...                         Parameter values
 #' @return
 #' A list containing the following elements: \describe{ \item{parameterizedSql}{The original
 #' parameterized SQL code} \item{sql}{The rendered sql} }
@@ -65,15 +67,21 @@ NULL
 #' renderSql("SELECT * FROM @@a {@@a == 'myTable' & @@b != 'x'}?{WHERE @@b = 1};",
 #'           a = "myTable",
 #'           b = "y")
+#' renderSql(sql = "SELECT * FROM @@a;", 
+#'           warnOnMissingParameters = FALSE, 
+#'           a = "myTable", 
+#'           b = "missingParameter")
 #' @import rJava
 #' @export
-renderSql <- function(sql = "", ...) {
+renderSql <- function(sql = "", warnOnMissingParameters = TRUE, ...) {
   parameters <- lapply(list(...), function(x) {
     paste(x, collapse = ",")
   })
-  messages <- rJava::J("org.ohdsi.sql.SqlRender")$check(sql, rJava::.jarray(names(parameters)), rJava::.jarray(as.character(parameters)))
-  for (message in messages) {
-    warning(message)
+  if (warnOnMissingParameters) {
+    messages <- rJava::J("org.ohdsi.sql.SqlRender")$check(sql, rJava::.jarray(names(parameters)), rJava::.jarray(as.character(parameters)))
+    for (message in messages) {
+      warning(message)
+    }
   }
   translatedSql <- rJava::J("org.ohdsi.sql.SqlRender")$renderSql(sql, rJava::.jarray(names(parameters)), rJava::.jarray(as.character(parameters)))
   list(originalSql = sql, sql = translatedSql, parameters = parameters)
